=====
konch
=====

.. image:: https://badge.fury.io/py/konch.svg
    :target: http://badge.fury.io/py/konch
    :alt: Latest version

.. image:: https://travis-ci.org/sloria/konch.svg?branch=master
    :target: https://travis-ci.org/sloria/konch
    :alt: Travis-CI

.. image:: https://readthedocs.org/projects/konch/badge/
   :target: http://konch.readthedocs.io/
   :alt: Documentation

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/ambv/black
   :alt: Code style: Black


Configures your Python shell
============================

**konch** is a CLI and configuration utility for the Python shell, optimized for simplicity and productivity.

- **Automatically import** any object upon startup
- **Simple**, per-project configuration in a single file (it's just Python code)
- **No external dependencies**
- Uses **IPython**, **BPython**, or **ptpython** if available, and falls back to built-in interpreter
- Automatically load **IPython extensions**
- Can have multiple configurations per project using **named configs**

.. image:: http://zippy.gfycat.com/EachTerrificChupacabra.gif
    :alt: Demo
    :target: http://konch.readthedocs.io


`http://konch.readthedocs.io <http://konch.readthedocs.io>`_
============================================================
